@@ -3,15 +3,26 @@ from typing import Optional, Union
 import h5py
 import zarr
 from anndata import AnnData
+from anndata._io.h5ad import read_dataframe_legacy as read_dataframe_legacy_h5
 from anndata._io.specs.methods import _read_partial
 from anndata._io.specs.registry import read_elem, read_elem_partial
-from lnschema_core import DObject
-from lnschema_core.dev._storage import filepath_from_dobject
+from anndata._io.zarr import read_dataframe_legacy as read_dataframe_legacy_zarr
+from lndb.dev.upath import infer_filesystem as _infer_filesystem
+from lnschema_core import File
+from lnschema_core._core import filepath_from_file_or_folder
 
-from .._filesystem import _infer_filesystem
 from ._lazy_field import LazySelector
 
 
+def _read_dataframe(elem: Union[zarr.Array, h5py.Dataset, zarr.Group, h5py.Group]):
+    if isinstance(elem, zarr.Array):
+        return read_dataframe_legacy_zarr(elem)
+    elif isinstance(elem, h5py.Dataset):
+        return read_dataframe_legacy_h5(elem)
+    else:
+        return read_elem(elem)
+
+
 def _indices(base_indices, select_indices):
     if len(base_indices) == len(select_indices):
         return slice(None)
@@ -25,8 +36,8 @@ def _subset_adata_storage(
     query_var: Optional[Union[str, LazySelector]] = None,
 ) -> Union[AnnData, None]:
     with storage as access:
-        obs = read_elem(access["obs"])
-        var = read_elem(access["var"])
+        obs = _read_dataframe(access["obs"])
+        var = _read_dataframe(access["var"])
 
         if query_obs is not None:
             if hasattr(query_obs, "evaluate"):
@@ -76,22 +87,22 @@ def _subset_adata_storage(
         return AnnData(**prepare_adata)
 
 
-def _subset_anndata_dobject(
-    dobject: DObject,
+def _subset_anndata_file(
+    file: File,
     query_obs: Optional[Union[str, LazySelector]] = None,
     query_var: Optional[Union[str, LazySelector]] = None,
 ) -> Union[AnnData, None]:
-    dobject_path = filepath_from_dobject(dobject)
-    fs, dobject_path_str = _infer_filesystem(dobject_path)
+    file_path = filepath_from_file_or_folder(file)
+    fs, file_path_str = _infer_filesystem(file_path)
 
     adata: Union[AnnData, None] = None
 
-    if dobject.suffix == ".h5ad":
-        with fs.open(dobject_path_str, mode="rb") as file:
+    if file.suffix == ".h5ad":
+        with fs.open(file_path_str, mode="rb") as file:
             storage = h5py.File(file, mode="r")
             adata = _subset_adata_storage(storage, query_obs, query_var)
-    elif dobject.suffix == ".zarr":
-        mapper = fs.get_mapper(dobject_path_str, check=True)
+    elif file.suffix == ".zarr":
+        mapper = fs.get_mapper(file_path_str, check=True)
         storage = zarr.open(mapper, mode="r")
         adata = _subset_adata_storage(storage, query_obs, query_var)
 
